@@ -51,6 +51,9 @@ Config.define('ORIGIN', '*', 'Access Control Allow Origin header value', 'Web')
 Config.define('HTTP_PROXY_HOST', None, 'HTTP Proxy Host to use', 'Web')
 Config.define('HTTP_PROXY_PORT', None, 'HTTP Proxy Port to use', 'Web')
 
+Config.define('API_PROXY_HOST', None, 'HTTP Proxy Host to use to connect to the API', 'Web')
+Config.define('API_PROXY_PORT', None, 'HTTP Proxy Port to use to connect to the API', 'Web')
+
 Config.define('COMMIT_ON_REQUEST_END', True, 'Commit on request end', 'DB')
 
 Config.define('REDISHOST', 'localhost', 'Redis host', 'Redis')
