@@ -11,21 +11,26 @@ class BaseHandler(RequestHandler):
     def initialize(self, *args, **kw):
         super(BaseHandler, self).initialize(*args, **kw)
 
-        self._session = None
+    def keep_alive(self):
+        return False
 
     def on_finish(self):
         if self.application.config.COMMIT_ON_REQUEST_END:
-            try:
-                if self.get_status() > 399:
-                    logging.debug('ROLLING BACK TRANSACTION')
-                    self.db.rollback()
-                else:
-                    logging.debug('COMMITTING TRANSACTION')
-                    self.db.commit()
-                    self.application.event_bus.flush()
-            finally:
-                self.db.close()
-                self._session = None
+            if self.get_status() > 399:
+                logging.debug('ROLLING BACK TRANSACTION')
+                self.db.rollback()
+            else:
+                logging.debug('COMMITTING TRANSACTION')
+                self.db.commit()
+                self.application.event_bus.flush()
+
+    def finish(self, chunk=None):
+        keep_alive = self.keep_alive()
+
+        if not keep_alive:
+            self.request.connection.no_keep_alive = False
+
+        super(BaseHandler, self).finish(chunk)
 
     def options(self):
         self.set_header('Access-Control-Allow-Origin', self.application.config.ORIGIN)
@@ -44,7 +49,8 @@ class BaseHandler(RequestHandler):
 
     @property
     def db(self):
-        if self._session is None:
-            self._session = self.application.get_sqlalchemy_session()
+        return self.application.db
+        #if self._session is None:
+            #self._session = self.application.get_sqlalchemy_session()
 
-        return self._session
+        #return self._session
