@@ -104,14 +104,14 @@ class Reviewer(object):
 
     def _get(self, url):
         if self.proxies:
-            logging.debug('Getting "%s" using proxy "%s:%s"...' % self.proxies.get('http', None))
+            logging.debug('Getting "%s" using proxy "%s"...' % (url, self.proxies.get('http', None)))
             return requests.get(url, proxies=self.proxies)
 
         return requests.get(url)
 
     def _post(self, url, data):
         if self.proxies:
-            logging.debug('Posting to "%s" using proxy "%s:%s"...' % self.proxies.get('http', None))
+            logging.debug('Posting to "%s" using proxy "%s"...' % (url, self.proxies.get('http', None)))
             return requests.post(url, data=data, proxies=self.proxies)
 
         return requests.post(url, data=data)
