@@ -12,6 +12,7 @@ class LinkCrawlerValidator(Validator):
     def __init__(self, *args, **kw):
         super(LinkCrawlerValidator, self).__init__(*args, **kw)
         self.url_buffer = set()
+        self.broken_links = set()
 
     def validate(self):
         links = self.get_links()
@@ -19,19 +20,28 @@ class LinkCrawlerValidator(Validator):
         for url, response in links:
             self.send_url(url, response)
 
+        if self.broken_links:
+            data = []
+            for index, url in enumerate(self.broken_links, start=1):
+                data.append('<a href="%s" target="_blank">Link #%s</a>' % (url, index))
+
+            self.add_violation(
+                key='broken.link',
+                title='A link is broken',
+                description=('A link from your page to "%s" is broken or the '
+                             'page failed to load in under 10 seconds. '
+                             'This can lead your site to lose rating with '
+                             'Search Engines and is misleading to users.') % (', '.join(data)),
+                points=100 * len(self.broken_links)
+            )
+
         self.flush()
 
     def test_url(self, url, response):
         status = response.status_code
 
         if status > 399:
-            self.add_violation(
-                key='broken.link',
-                title='A link is broken',
-                description=('A link from your page to "%s" is broken or the page failed to load in under 10 seconds. '
-                    'This can lead your site to lose rating with Search Engines and is misleading to users.') % url,
-                points=100
-            )
+            self.broken_links.add(url)
             return False
 
         if status == 302 or status == 307:
@@ -63,6 +73,7 @@ class LinkCrawlerValidator(Validator):
 
         self.enqueue(*self.url_buffer)
         self.url_buffer = []
+        self.broken_links = []
 
     def get_links(self):
         return self.review.data['page.links']
